# Debug drive reports

Debug drive reports allow you to mock drive reports for individual drivers in a circle, which will
appear in the Driving tab. Individual reports are also aggregated and grouped into the Driving tab's
"All" sub-tab. This means you can test much of the Driving tab UI without needing real drives to
have taken place, which makes drive reports more testable as issues with the UI are more easily
reproduced. For now, only weekly drive reports can be mocked in this way; individual drive mocking
may come in the future. In the meantime, real drive data is supplied wherever it can't be mocked.
Because this utility is meant to be used on any circle without additional setup, data is attributed
to real members in the order they are viewed; see the comments in the JSON schema below for details.

To enable debug drive reports, go to the debug settings menu in the app, click on "Enable debug
drive reports". The `reports.json` file will be used. You will have to fully restart the app for
changes to take effect.

## Debug drive reports JSON schema

The JSON schema for debug drive reports looks like this:

```json5
// The top level element is an array. This array contains one element per member, each representing
// that member's set of daily drive reports. This mocked data is attributed to real members in the
// order that their Driving tab sub-tab is viewed. For example, the first individual member tapped
// in the Driving tab will be assigned to the data of the first element, the second member tapped
// will be assigned to the data of the second element, and so on. If there are more members in a
// circle than there are elements in this array, the members viewed last will be shown with the "no
// drives detected" message.
[
  // This array represents a single member's set of daily drive reports. This data is always begins
  // with today and goes backwards - the first element contains information about today, the second
  // element contains information about yesterday, and so on.
  [
    // This is a drive report for a single member on a single day. If no data should be visible,
    // this entire object can be replaced with null, and the "no drives detected" message will be
    // shown.
    {
      // The total distance traveled by the member, in meters, on this day.
      "total_distance_meters": 20000.0,

      // The top speed driven by the member, in meters per second, on this day.
      "top_speed_meters_per_sec": 35.0,

      // The total number of drives made by the member that occurred on this day.
      "total_drives": 8,

      // The total number of high speed events (driving over 80mph for at least 30sec) on this day.
      "total_high_speed_events": 0,

      // The total number of phone usage events (suspected distracted driving) on this day.
      "total_phone_usage_events": 0,

      // The total number of hard braking events (rapid deceleration) on this day.
      "total_hard_braking_events": 0,

      // The total number of rapid acceleration events on this day.
      "total_rapid_acceleration_events": 0
    }
  ]
]
```
